# Ambit-Stochastics
A repository dedicated to the study of Ambit fields and Trawl processes

The `Trawl processes example usage` and `Simple ambit field` jupyter notebooks in the root folder explains the functionality of the library. The full documentation is available at https://danleonte.github.io/Ambit_Stochastics/index.html
